RouteCollection class
The declared route tree + the hierarchical matcher.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
routes
→ List<
ModularRoute> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
ModularRoute route) → void -
match(
Uri uri) → List< RouteLevel> ? -
Matches
urito a chain of routes (root → leaf) with params, ornull. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited