ModularContext class abstract
The single surface a module declares itself through: DI registration
(add*), routes (route, with guards/transition/nested children),
and the unified module include verb.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add<
T> (Function constructor) → void -
addInstance<
T> (T instance) → void -
addLazySingleton<
T> (Function constructor) → void -
addSingleton<
T> (Function constructor) → void -
module(
Module module, {String? at}) → void -
Include another module. The mount path is
at??module.path: -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
route(
String path, {required ModularWidgetBuilder child, void provide(Scoped scoped)?, void children(ModularContext c)?, List< ModularGuard> ? guards, PageTransition? transition}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited